==============
AWS SSH Helper
==============


.. image:: https://img.shields.io/pypi/v/jh-awssh.svg
        :target: https://pypi.python.org/pypi/jh-awssh

.. image:: https://img.shields.io/travis/ibejohn818/awssh.svg
        :target: https://travis-ci.org/ibejohn818/awssh

.. image:: https://readthedocs.org/projects/awssh/badge/?version=latest
        :target: https://awssh.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/ibejohn818/awssh/shield.svg
     :target: https://pyup.io/repos/github/ibejohn818/awssh/
     :alt: Updates

Install
---------------
|`pip install jh-awssh`
| or use sudo on OS X
| `sudo -H pip install jh-awssh`


SSH Connect to Ec2 instances & list IP for use with **mussh**

Run `$: awssh` to see a list of all commands



* Free software: MIT license
